Front Matter — dogpile.cache 0.6.2 documentation

# Front Matter

Information about the dogpile.cache project.

## Project Homepage

dogpile.cache is hosted on Bitbucket - the lead project page is at https://bitbucket.org/zzzeek/dogpile.cache. Source code is tracked here using Git.

Releases and project status are available on Pypi at http://pypi.python.org/pypi/dogpile.cache.

The most recent published version of this documentation should be at http://dogpilecache.readthedocs.org.

## Installation

Install released versions of dogpile.cache from the Python package index with pip or a similar tool:

    pip install dogpile.cache

## Bugs

Bugs and feature enhancements to dogpile.cache should be reported on the Bitbucket issue tracker.